# Caching

Speed up repeated requests by caching GET responses. Use `flask-caching` for
production backends or a bundled simple cache for development.

## Sections

- [Backends](backends.md)
- [Example](example.md)
